pub enum ConstrainScaleBehavior {
Fit,
Zoom,
Stretch,
CutOff,
}Expand description
Defines the scale behavior for the constrain
Variants
Fit
Fit the element into the size, nothing will be cropped
Zoom
Zoom the element into the size, crops if the aspect ratio of the element does not match the aspect of the constrain size
Stretch
Always stretch the element to the constrain size
CutOff
Do not scale, but cut off at the constrain size