pub struct Uniform<'a> {
pub name: Cow<'a, str>,
pub value: UniformValue,
}Available on crate feature
renderer_gl only.Expand description
A shader uniform variable consisting out of a name and value
Fields
name: Cow<'a, str>name of the uniform
value: UniformValuevalue of the uniform
Implementations
Sourceimpl<'a> Uniform<'a>
impl<'a> Uniform<'a>
Sourcepub fn new(
name: impl Into<Cow<'a, str>>,
value: impl Into<UniformValue>,
) -> Uniform<'a>
pub fn new( name: impl Into<Cow<'a, str>>, value: impl Into<UniformValue>, ) -> Uniform<'a>
Create a new uniform variable value
Sourcepub fn to_owned(&self) -> Uniform<'static>
pub fn to_owned(&self) -> Uniform<'static>
Convert the uniform to a static lifetime, cloning the contents
Sourcepub fn into_owned(self) -> Uniform<'static>
pub fn into_owned(self) -> Uniform<'static>
Convert the uniform to a static lifetime, cloning the name if necessary