Enum PixmanError

pub enum PixmanError {
Show 14 variants UnsupportedNumberOfPlanes, UnsupportedPixelFormat(DrmFourcc), UnsupportedModifier(DrmModifier), UnsupportedWlPixelFormat(Format), IncompleteBuffer { expected: usize, actual: usize, }, BufferAccessError(BufferAccessError), ImportFailed, BufferDestroyed, Map(DmabufMappingFailed), Sync(DmabufSyncFailed), Failed(OperationFailed), NoTargetBound, Unsupported, SyncInterrupted,
}
Available on crate feature renderer_pixman only.
Error returned during rendering using pixman

Variants



UnsupportedNumberOfPlanes

The given buffer has an unsupported number of planes



UnsupportedPixelFormat(DrmFourcc)

The given buffer has an unsupported pixel format



UnsupportedModifier(DrmModifier)

The given buffer has an unsupported modifier



UnsupportedWlPixelFormat(Format)

Available on crate feature wayland_frontend only.

The given wl buffer has an unsupported pixel format



IncompleteBuffer

The given buffer is incomplete

Fields

expected: usize

Expected len of the buffer

actual: usize

Actual len of the buffer



BufferAccessError(BufferAccessError)

Available on crate feature wayland_frontend only.

The given buffer was not accessible



ImportFailed

Failed to import the given buffer



BufferDestroyed

The underlying buffer has been destroyed



Map(DmabufMappingFailed)

Mapping the buffer failed



Sync(DmabufSyncFailed)

Synchronizing access to the buffer failed



Failed(OperationFailed)

The requested operation failed



NoTargetBound

No target is currently bound



Unsupported

The requested operation is not supported



SyncInterrupted

Blocking for a synchronization primitive failed