pub struct ConstrainBehavior {
pub reference: ConstrainReference,
pub behavior: ConstrainScaleBehavior,
pub align: ConstrainAlign,
}Available on crate feature
desktop only.Expand description
Defines the behavior for constrain_space_element
Fields
reference: ConstrainReferenceDefines what should be used as the reference for calculating the scale
behavior: ConstrainScaleBehaviorDefines how the element should be scaled
align: ConstrainAlignDefines the alignment of the element inside of the constrain