Struct Xkb

pub struct Xkb { /* private fields */ }
An xkbcommon context, keymap, and state, that can be sent to another thread, but should not have additional ref-counts kept on one thread.

Implementations

Source

impl Xkb

pub unsafe fn context(&self) -> &Context

The xkbcommon context.

Safety

A ref-count of the context should not outlive the Xkb

pub unsafe fn keymap(&self) -> &Keymap

The xkbcommon keymap.

Safety

A ref-count of the keymap should not outlive the Xkb

pub unsafe fn state(&self) -> &State

The xkbcommon state.

Safety

A ref-count of the state should not outlive the Xkb

pub fn active_layout(&self) -> Layout

Get the active layout of the keyboard.

pub fn layout_name(&self, layout: Layout) -> &str

Get the human readable name for the layout.

pub fn layouts(&self) -> impl Iterator<Item = Layout>

Iterate over layouts present in the keymap.

pub fn raw_syms_for_key_in_layout( &self, keycode: Keycode, layout: Layout, ) -> &[Keysym]

Returns the syms for the underlying keycode without any modifications by the current keymap state applied.