pub type LevelIndex = u32;Expand description
Index of a shift level.
Any key, in any layout, can have several shift levels Each
shift level can assign different keysyms to the key. The shift level
to use is chosen according to the current keyboard state; for example,
if no keys are pressed, the first level may be used; if the Left Shift
key is pressed, the second; if Num Lock is pressed, the third; and
many such combinations are possible (see ModIndex).
Level indices are consecutive. The first level has index 0.