pub enum VrrSupport {
NotSupported,
RequiresModeset,
Supported,
}Available on crate feature
backend_drm only.Expand description
VRR support state
Variants
NotSupported
VRR is generally not supported
RequiresModeset
VRR is supported, but changing it requires a modeset
Supported
VRR is supported and can be changed without a modeset