pub enum Error<R: GraphicsApi, T: GraphicsApi>where
R::Error: 'static,
T::Error: 'static,
<<R::Device as ApiDevice>::Renderer as RendererSuper>::Error: 'static,
<<T::Device as ApiDevice>::Renderer as RendererSuper>::Error: 'static,{
RenderApiError(R::Error),
TargetApiError(T::Error),
NoDevice(DrmNode),
MismatchedDevice(DrmNode),
DeviceMissing,
Render(<<R::Device as ApiDevice>::Renderer as RendererSuper>::Error),
Target(<<T::Device as ApiDevice>::Renderer as RendererSuper>::Error),
ImportFailed,
AllocatorError(AnyError),
}Available on crate feature
renderer_multi only.Expand description
Errors generated by GpuManager and MultiRenderer.
Variants
RenderApiError(R::Error)
The graphics api errored on device enumeration
TargetApiError(T::Error)
The graphics api errored on device enumeration
NoDevice(DrmNode)
The graphics api has found no node matching the drm node
MismatchedDevice(DrmNode)
The device requested did not match the expected
DeviceMissing
The device has gone missing
Render(<<R::Device as ApiDevice>::Renderer as RendererSuper>::Error)
Error on the rendering device
Target(<<T::Device as ApiDevice>::Renderer as RendererSuper>::Error)
Error on the target device
ImportFailed
Failed to import buffer using the api on any device
AllocatorError(AnyError)
Buffer allocation failed