pub struct Xkb { /* private fields */ }Expand description
An xkbcommon context, keymap, and state, that can be sent to another thread, but should not have additional ref-counts kept on one thread.
Implementations
Sourceimpl Xkb
impl Xkb
Sourcepub fn active_layout(&self) -> Layout
pub fn active_layout(&self) -> Layout
Get the active layout of the keyboard.
Sourcepub fn layout_name(&self, layout: Layout) -> &str
pub fn layout_name(&self, layout: Layout) -> &str
Get the human readable name for the layout.
Sourcepub fn layouts(&self) -> impl Iterator<Item = Layout>
pub fn layouts(&self) -> impl Iterator<Item = Layout>
Iterate over layouts present in the keymap.
Sourcepub fn raw_syms_for_key_in_layout(
&self,
keycode: Keycode,
layout: Layout,
) -> &[Keysym]
pub fn raw_syms_for_key_in_layout( &self, keycode: Keycode, layout: Layout, ) -> &[Keysym]
Returns the syms for the underlying keycode without any modifications by the current keymap state applied.