pub fn request_data_device_client_selection<D>(
seat: &Seat<D>,
mime_type: String,
fd: OwnedFd,
) -> Result<(), SelectionRequestError>where
D: SeatHandler + DataDeviceHandler + 'static,Available on crate feature
wayland_frontend only.Expand description
Request the current data_device selection of the given seat to be written to the provided file descriptor in the given mime type.